@@ -1613,7 +1613,7 @@ static sw_inline swConnection* swReactor_get(swReactor *reactor, int fd)
     {
         return &reactor->socket_list[fd];
     }
-    swConnection *socket = swArray_alloc(reactor->socket_array, fd);
+    swConnection *socket = (swConnection*) swArray_alloc(reactor->socket_array, fd);
     if (socket == NULL)
     {
         return NULL;
@@ -1904,8 +1904,7 @@ typedef struct
     uint32_t reactor_ready :1;
     uint32_t in_client :1;
     uint32_t shutdown :1;
-    uint32_t reload;
-    uint32_t reload_count;
+    uint32_t wait_exit :1;
     uint32_t request_count;
 
     int max_request;
