@@ -124,7 +124,14 @@ int swFactory_end(swFactory *factory, int fd)
         if (serv->onClose != NULL)
         {
             info.fd = fd;
-            info.from_id = -1;
+            if (conn->close_actively)
+            {
+                info.from_id = -1;
+            }
+            else
+            {
+                info.from_id = conn->from_id;
+            }
             info.from_fd = conn->from_fd;
             serv->onClose(serv, &info);
         }
