@@ -24,11 +24,11 @@ typedef struct
     uint8_t reloading;
     uint8_t reload_event_worker;
     uint8_t reload_task_worker;
+    uint8_t read_message;
 
 } swManagerProcess;
 
-static int swManager_loop_async(swFactory *factory);
-static int swManager_loop_sync(swFactory *factory);
+static int swManager_loop(swFactory *factory);
 static void swManager_signal_handle(int sig);
 static pid_t swManager_spawn_worker(swFactory *factory, int worker_id);
 static void swManager_check_exit_status(swServer *serv, int worker_id, pid_t pid, int status);
@@ -39,7 +39,7 @@ static swManagerProcess ManagerProcess;
 int swManager_start(swFactory *factory)
 {
     swFactoryProcess *object = factory->object;
-    int i, ret;
+    int i;
     pid_t pid;
     swServer *serv = factory->ptr;
 
@@ -110,10 +110,16 @@ int swManager_start(swFactory *factory)
         }
     }
 
+    serv->message_box = swChannel_new(65536, sizeof(swWorkerStopMessage), SW_CHAN_LOCK | SW_CHAN_SHM);
+    if (serv->message_box == NULL)
+    {
+        return SW_ERR;
+    }
+
     pid = fork();
     switch (pid)
     {
-    //创建manager进程
+    //fork manager process
     case 0:
         //wait master process
         SW_START_SLEEP;
@@ -166,19 +172,9 @@ int swManager_start(swFactory *factory)
             }
         }
 
-        //标识为管理进程
         SwooleG.process_type = SW_PROCESS_MANAGER;
         SwooleG.pid = getpid();
-
-        if (serv->reload_async)
-        {
-            ret = swManager_loop_async(factory);
-        }
-        else
-        {
-            ret = swManager_loop_sync(factory);
-        }
-        exit(ret);
+        exit(swManager_loop(factory));
         break;
 
         //master process
@@ -204,247 +200,12 @@ static void swManager_check_exit_status(swServer *serv, int worker_id, pid_t pid
     }
 }
 
-static int swManager_loop_async(swFactory *factory)
-{
-    pid_t pid, new_pid;
-    int i;
-    int reload_worker_num;
-    int ret;
-    int status;
-
-    //hashMap 存储oid_pid ->new_pid的映射
-    swHashMap *pidMap = swHashMap_new(SW_HASHMAP_INIT_BUCKET_N, NULL);
-    if (pidMap == NULL)
-    {
-        swError("swHashMap_new failed");
-        return SW_ERR;
-    }
-
-    SwooleG.use_signalfd = 0;
-    SwooleG.use_timerfd = 0;
-
-    memset(&ManagerProcess, 0, sizeof(ManagerProcess));
-
-    swServer *serv = factory->ptr;
-    swWorker *reload_workers;
-
-    if (serv->onManagerStart)
-    {
-        serv->onManagerStart(serv);
-    }
-
-    reload_worker_num = serv->worker_num + SwooleG.task_worker_num;
-    reload_workers = sw_calloc(reload_worker_num, sizeof(swWorker));
-    if (reload_workers == NULL)
-    {
-        swError("malloc[reload_workers] failed");
-        return SW_ERR;
-    }
-
-    //for reload
-    swSignal_add(SIGHUP, NULL);
-    swSignal_add(SIGTERM, swManager_signal_handle);
-    swSignal_add(SIGUSR1, swManager_signal_handle);
-    swSignal_add(SIGUSR2, swManager_signal_handle);
-    //swSignal_add(SIGINT, swManager_signal_handle);
-
-    SwooleG.main_reactor = NULL;
-
-    while (SwooleG.running > 0)
-    {
-        pid = wait(&status);
-
-        if (pid < 0)
-        {
-            //pid < 0 代表manager进程收到reload信号量，将进程组复制到reload进程组，fork新的进程组
-            if (ManagerProcess.reloading == 0)
-            {
-                swTrace("wait() failed. Error: %s [%d]", strerror(errno), errno);
-            }
-            else if (ManagerProcess.reload_event_worker == 1)
-            {
-                swNotice("worker is reloading now.");
-                memcpy(reload_workers, serv->workers, sizeof(swWorker) * serv->worker_num);
-                reload_worker_num = serv->worker_num;
-
-                if (SwooleG.task_worker_num > 0)
-                {
-                    memcpy(reload_workers + serv->worker_num, SwooleGS->task_workers.workers,
-                            sizeof(swWorker) * SwooleG.task_worker_num);
-                    reload_worker_num += SwooleG.task_worker_num;
-                }
-                ManagerProcess.reload_event_worker = 0;
-                goto kill_workers;
-            }
-            else if (ManagerProcess.reload_task_worker == 1)
-            {
-                swNotice("task is reloading now.");
-                if (SwooleG.task_worker_num == 0)
-                {
-                    swWarn("cannot reload workers, because server no have task workers.");
-                    continue;
-                }
-                memcpy(reload_workers, SwooleGS->task_workers.workers, sizeof(swWorker) * SwooleG.task_worker_num);
-                reload_worker_num = SwooleG.task_worker_num;
-
-                ManagerProcess.reload_task_worker = 0;
-                goto kill_workers;
-            }            
-        }
-        if (SwooleG.running == 1)
-        {
-            /* 回收worker */
-            for (i = 0; i < serv->worker_num; i++)
-            {
-                //compare PID
-                if (pid != serv->workers[i].pid)
-                {
-                    continue;
-                }
-                else
-                {
-                    swManager_check_exit_status(serv, i, pid, status);
-
-                    //pid ->new pid
-                    new_pid = (pid_t) (long) swHashMap_find_int(pidMap, pid);
-                    swWarn(" now the worker pid is %d", new_pid);
-                    serv->workers[i].pid = new_pid;
-                }
-            }
-
-            if (pid > 0)
-            {
-                swWarn(" pid %d is not in the workers need to exit", pid);
-                swWorker *exit_worker;
-                //task worker
-                if (SwooleGS->task_workers.map)
-                {
-                    exit_worker = swHashMap_find_int(SwooleGS->task_workers.map, pid);
-                    if (exit_worker != NULL)
-                    {
-                        swManager_check_exit_status(serv, exit_worker->id, pid, status);
-                        if (exit_worker->deleted == 1)  //主动回收不重启
-                        {
-                            exit_worker->deleted = 0;
-                        }
-                        else
-                        {
-                            swProcessPool_spawn(exit_worker);
-                        }
-                    }
-                }
-                //user process
-                if (serv->user_worker_map != NULL)
-                {
-                    swManager_wait_user_worker(&SwooleGS->event_workers, pid);
-                }
-            }
-        }
-
-        kill_workers: if (ManagerProcess.reloading == 1)
-        {
-            for (i = 0; i < serv->worker_num; i++)
-            {
-                /* 先fork新的 再kill老的*/
-                while (1)
-                {
-                    new_pid = swManager_spawn_worker(factory, i);
-                    if (new_pid < 0)
-                    {
-                        usleep(100000);
-                        continue;
-                    }
-                    else
-                    {
-                        swHashMap_add_int(pidMap, reload_workers[i].pid, (void*) (long) new_pid);
-                        swWarn(" add pidMap new_pid is %d old pid is %d", new_pid, reload_workers[i].pid);
-                        break;
-                    }
-                }
-
-                swWarn(" kill the reload workers %d", reload_workers[i].pid);
-                ret = kill(reload_workers[i].pid, SIGUSR1);
-                if (ret < 0)
-                {
-                    swSysError("kill(%d, SIGTERM) failed.", reload_workers[i].pid);
-                }  
-            }
-            ManagerProcess.reloading = 0;
-        }
-    } 
-
-    sw_free(reload_workers);
-
-    //kill all child process
-    for (i = 0; i < serv->worker_num; i++)
-    {
-        swTrace("[Manager]kill worker processor");
-        kill(serv->workers[i].pid, SIGTERM);
-    }
-
-    //wait child process
-    for (i = 0; i < serv->worker_num; i++)
-    {
-        if (swWaitpid(serv->workers[i].pid, &status, 0) < 0)
-        {
-            swSysError("waitpid(%d) failed.", serv->workers[i].pid);
-        }
-    }
-
-    //kill and wait task process
-    if (SwooleG.task_worker_num > 0)
-    {
-        swProcessPool_shutdown(&SwooleGS->task_workers);
-    }
-
-    if (serv->user_worker_map)
-    {
-        swWorker* user_worker;
-        uint64_t key;
-
-        //kill user process
-        while (1)
-        {
-            user_worker = swHashMap_each_int(serv->user_worker_map, &key);
-            //hashmap empty
-            if (user_worker == NULL)
-            {
-                break;
-            }
-            kill(user_worker->pid, SIGTERM);
-        }
-
-        //wait user process
-        while (1)
-        {
-            user_worker = swHashMap_each_int(serv->user_worker_map, &key);
-            //hashmap empty
-            if (user_worker == NULL)
-            {
-                break;
-            }
-            if (swWaitpid(user_worker->pid, &status, 0) < 0)
-            {
-                swSysError("waitpid(%d) failed.", serv->workers[i].pid);
-            }
-        }
-    }
-
-    if (serv->onManagerStop)
-    {
-        serv->onManagerStop(serv);
-    }
-    swHashMap_free(pidMap);
-    return SW_OK;   
-}
-
-static int swManager_loop_sync(swFactory *factory)
+static int swManager_loop(swFactory *factory)
 {
     int pid, new_pid;
     int i;
     int reload_worker_i = 0;
     int reload_worker_num;
-    int ret;
     int status;
 
     SwooleG.use_signalfd = 0;
@@ -473,6 +234,7 @@ static int swManager_loop_sync(swFactory *factory)
     swSignal_add(SIGTERM, swManager_signal_handle);
     swSignal_add(SIGUSR1, swManager_signal_handle);
     swSignal_add(SIGUSR2, swManager_signal_handle);
+    swSignal_add(SIGIO, swManager_signal_handle);
 #ifdef SIGRTMIN
     swSignal_add(SIGRTMIN, swManager_signal_handle);
 #endif
@@ -486,7 +248,25 @@ static int swManager_loop_sync(swFactory *factory)
 
         if (pid < 0)
         {
-            if (ManagerProcess.reloading == 0)
+            if (ManagerProcess.read_message)
+            {
+                swWorkerStopMessage msg;
+                while (swChannel_pop(serv->message_box, &msg, sizeof(msg)) > 0)
+                {
+                    if (SwooleG.running == 0)
+                    {
+                        continue;
+                    }
+                    pid_t new_pid = swManager_spawn_worker(factory, msg.worker_id);
+                    if (new_pid > 0)
+                    {
+                        serv->workers[msg.worker_id].pid = new_pid;
+                    }
+                }
+                ManagerProcess.read_message = 0;
+                goto kill_worker;
+            }
+            else if (ManagerProcess.reloading == 0)
             {
                 swTrace("wait() failed. Error: %s [%d]", strerror(errno), errno);
             }
@@ -587,8 +367,7 @@ static int swManager_loop_sync(swFactory *factory)
                 reload_worker_i = 0;
                 continue;
             }
-            ret = kill(reload_workers[reload_worker_i].pid, SIGTERM);
-            if (ret < 0)
+            if (kill(reload_workers[reload_worker_i].pid, SIGTERM) < 0)
             {
                 swSysError("kill(%d, SIGTERM) failed.", reload_workers[reload_worker_i].pid);
             }
@@ -684,6 +463,9 @@ static void swManager_signal_handle(int sig)
             ManagerProcess.reload_task_worker = 1;
         }
         break;
+    case SIGIO:
+        ManagerProcess.read_message = 1;
+        break;
     default:
 #ifdef SIGRTMIN
         if (sig == SIGRTMIN)
