@@ -88,14 +88,14 @@ int swReactorSelect_add(swReactor *reactor, int fd, int fdtype)
         swWarn("max fd value is FD_SETSIZE(%d).\n", FD_SETSIZE);
         return SW_ERR;
     }
-    if (swReactor_add(reactor, fd, fdtype) < 0)
-    {
-        return SW_ERR;
-    }
     swReactorSelect *object = reactor->object;
     swFdList_node *ev = sw_malloc(sizeof(swFdList_node));
+    if (ev == NULL)
+    {
+        swWarn("malloc(%ld) failed.", sizeof(swFdList_node));
+        return SW_ERR;
+    }
     ev->fd = fd;
-    //select需要保存原始的值
     ev->fdtype = fdtype;
     LL_APPEND(object->fds, ev);
     reactor->event_num++;
@@ -103,6 +103,7 @@ int swReactorSelect_add(swReactor *reactor, int fd, int fdtype)
     {
         object->maxfd = fd;
     }
+    swReactor_add(reactor, fd, fdtype);
     return SW_OK;
 }
 
@@ -116,12 +117,6 @@ int swReactorSelect_del(swReactor *reactor, int fd)
     swReactorSelect *object = reactor->object;
     swFdList_node ev, *s_ev = NULL;
     ev.fd = fd;
-
-    if (swReactor_del(reactor, fd) < 0)
-    {
-        return SW_ERR;
-    }
-
     LL_SEARCH(object->fds, s_ev, &ev, swReactorSelect_cmp);
     if (s_ev == NULL)
     {
@@ -134,6 +129,7 @@ int swReactorSelect_del(swReactor *reactor, int fd)
     SW_FD_CLR(fd, &object->efds);
     reactor->event_num = reactor->event_num <= 0 ? 0 : reactor->event_num - 1;
     sw_free(s_ev);
+    swReactor_del(reactor, fd);
     return SW_OK;
 }
 
