@@ -112,12 +112,12 @@ static PHP_METHOD(swoole_buffer, __construct)
 
     if (size < 1)
     {
-        zend_throw_exception(swoole_exception_class_entry_ptr, "buffer size cannot be less than 0.", SW_ERROR_INVALID_PARAMS TSRMLS_CC);
+        zend_throw_exception(swoole_exception_class_entry_ptr, "buffer size can't be less than 0.", SW_ERROR_INVALID_PARAMS TSRMLS_CC);
         RETURN_FALSE;
     }
     else if (size > SW_STRING_BUFFER_MAXLEN)
     {
-        zend_throw_exception_ex(swoole_exception_class_entry_ptr, errno TSRMLS_CC, "buffer size must not exceed %d", SW_STRING_BUFFER_MAXLEN);
+        zend_throw_exception_ex(swoole_exception_class_entry_ptr, errno TSRMLS_CC, "buffer size can't exceed %d", SW_STRING_BUFFER_MAXLEN);
         RETURN_FALSE;
     }
 
@@ -160,7 +160,7 @@ static PHP_METHOD(swoole_buffer, append)
 
     if ((str.length + buffer->length) > buffer->size && (str.length + buffer->length) > SW_STRING_BUFFER_MAXLEN)
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "buffer size must not exceed %d", SW_STRING_BUFFER_MAXLEN);
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "buffer size can't exceed %d", SW_STRING_BUFFER_MAXLEN);
         RETURN_FALSE;
     }
 
@@ -208,7 +208,7 @@ static PHP_METHOD(swoole_buffer, substr)
     }
     if (offset + length > buffer->length)
     {
-        swoole_php_error(E_WARNING, "offset(%ld, %ld) out of bounds.", offset, length);
+        swoole_php_error(E_WARNING, "offset(%ld, %ld) is out of bounds.", offset, length);
         RETURN_FALSE;
     }
     if (remove)
@@ -244,7 +244,7 @@ static PHP_METHOD(swoole_buffer, write)
 
     if (str.length < 1)
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "string empty.");
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "string to write is empty.");
         RETURN_FALSE;
     }
 
@@ -256,7 +256,7 @@ static PHP_METHOD(swoole_buffer, write)
     }
     if (offset < 0)
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "offset(%ld) out of bounds.", offset);
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "offset(%ld) is out of bounds.", offset);
         RETURN_FALSE;
     }
 
@@ -264,7 +264,7 @@ static PHP_METHOD(swoole_buffer, write)
 
     if ((str.length + offset) > buffer->size && (str.length + offset) > SW_STRING_BUFFER_MAXLEN)
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "buffer size must not exceed %d", SW_STRING_BUFFER_MAXLEN);
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "buffer size can't exceed %d", SW_STRING_BUFFER_MAXLEN);
         RETURN_FALSE;
     }
 
@@ -303,7 +303,7 @@ static PHP_METHOD(swoole_buffer, read)
     }
     if (offset < 0)
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "offset(%ld) out of bounds.", offset);
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "offset(%ld) is out of bounds.", offset);
         RETURN_FALSE;
     }
 
@@ -330,7 +330,7 @@ static PHP_METHOD(swoole_buffer, expand)
 
     if (size <= buffer->size)
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "new size must more than %ld", buffer->size);
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "new size must be more than %ld", buffer->size);
         RETURN_FALSE;
     }
 
