@@ -46,6 +46,27 @@ static int php_swoole_event_onWrite(swReactor *reactor, swEvent *event);
 static int php_swoole_event_onError(swReactor *reactor, swEvent *event);
 static void php_swoole_event_onDefer(void *_cb);
 
+static void free_event_callback(void* data)
+{
+    php_reactor_fd *ev_set = (php_reactor_fd*) data;
+    if (ev_set->cb_read)
+    {
+        sw_zval_ptr_dtor(&(ev_set->cb_read));
+        ev_set->cb_read = NULL;
+    }
+    if (ev_set->cb_write)
+    {
+        sw_zval_ptr_dtor(&(ev_set->cb_write));
+        ev_set->cb_write = NULL;
+    }
+    if (ev_set->socket)
+    {
+        sw_zval_ptr_dtor(&(ev_set->socket));
+        ev_set->socket = NULL;
+    }
+    efree(ev_set);
+}
+
 static int php_swoole_event_onRead(swReactor *reactor, swEvent *event)
 {
     zval *retval;
@@ -193,6 +214,10 @@ void php_swoole_event_wait()
         {
             swoole_php_fatal_error(E_ERROR, "reactor wait failed. Error: %s [%d]", strerror(errno), errno);
         }
+        if (SwooleG.timer.map)
+        {
+            php_swoole_clear_all_timer();
+        }
     }
 }
 
@@ -353,6 +378,10 @@ PHP_FUNCTION(swoole_event_add)
         sw_zval_add_ref(&cb_read);
         sw_copy_to_stack(reactor_fd->cb_read, reactor_fd->stack.cb_read);
     }
+    else
+    {
+        reactor_fd->cb_read = NULL;
+    }
 
     if (cb_write!= NULL && !ZVAL_IS_NULL(cb_write))
     {
@@ -367,6 +396,10 @@ PHP_FUNCTION(swoole_event_add)
         sw_zval_add_ref(&cb_write);
         sw_copy_to_stack(reactor_fd->cb_write, reactor_fd->stack.cb_write);
     }
+    else
+    {
+        reactor_fd->cb_write = NULL;
+    }
 
     php_swoole_check_reactor();
     swSetNonBlock(socket_fd); //must be nonblock
@@ -553,7 +586,8 @@ PHP_FUNCTION(swoole_event_del)
     swConnection *socket = swReactor_get(SwooleG.main_reactor, socket_fd);
     if (socket->object)
     {
-        efree(socket->object);
+        SwooleG.main_reactor->defer(SwooleG.main_reactor, free_event_callback, socket->object);
+        socket->object = NULL;
     }
     socket->active = 0;
     int ret = 0;
