@@ -39,7 +39,7 @@ zval *php_sw_server_callbacks[PHP_SERVER_CALLBACK_NUM];
 #ifdef PHP_SWOOLE_ENABLE_FASTCALL
 zend_fcall_info_cache *php_sw_server_caches[PHP_SERVER_CALLBACK_NUM];
 #endif
-static swHashMap *task_callbacks;
+static swHashMap *task_callbacks = NULL;
 
 #if PHP_MAJOR_VERSION >= 7
 zval _php_sw_server_callbacks[PHP_SERVER_CALLBACK_NUM];
@@ -51,6 +51,7 @@ static void php_swoole_onStart(swServer *);
 static void php_swoole_onShutdown(swServer *);
 static void php_swoole_onWorkerStart(swServer *, int worker_id);
 static void php_swoole_onWorkerStop(swServer *, int worker_id);
+static void php_swoole_onWorkerExit(swServer *serv, int worker_id);
 static void php_swoole_onUserWorkerStart(swServer *serv, swWorker *worker);
 static int php_swoole_onTask(swServer *, swEventData *task);
 static int php_swoole_onFinish(swServer *, swEventData *task);
@@ -120,7 +121,7 @@ int php_swoole_task_pack(swEventData *task, zval *data TSRMLS_DC)
     {
         if (swTaskWorker_large_pack(task, task_data_str, task_data_len) < 0)
         {
-            swoole_php_fatal_error(E_WARNING, "large task pack failed().");
+            swoole_php_fatal_error(E_WARNING, "large task pack failed.");
             task->info.fd = SW_ERR;
         }
     }
@@ -234,7 +235,7 @@ static sw_inline int php_swoole_check_task_param(int dst_worker_id TSRMLS_DC)
 {
     if (SwooleG.task_worker_num < 1)
     {
-        swoole_php_fatal_error(E_WARNING, "Task method cannot use, Please set task_worker_num.");
+        swoole_php_fatal_error(E_WARNING, "task method can't be executed, please set 'task_worker_num' > 0.");
         return SW_ERR;
     }
 
@@ -246,7 +247,7 @@ static sw_inline int php_swoole_check_task_param(int dst_worker_id TSRMLS_DC)
 
     if (!swIsWorker())
     {
-        swoole_php_fatal_error(E_WARNING, "The method can only be used in the worker process.");
+        swoole_php_fatal_error(E_WARNING, "task method can only be used in the worker process.");
         return SW_ERR;
     }
 
@@ -356,7 +357,7 @@ void php_swoole_server_before_start(swServer *serv, zval *zobject TSRMLS_DC)
      */
     if (swServer_create(serv) < 0)
     {
-        swoole_php_fatal_error(E_ERROR, "create server failed. Error: %s", sw_error);
+        swoole_php_fatal_error(E_ERROR, "failed to create the server. Error: %s", sw_error);
         return;
     }
 
@@ -429,6 +430,10 @@ void php_swoole_register_callback(swServer *serv)
     {
         serv->onWorkerStop = php_swoole_onWorkerStop;
     }
+    if (php_sw_server_callbacks[SW_SERVER_CB_onWorkerExit] != NULL)
+    {
+        serv->onWorkerExit = php_swoole_onWorkerExit;
+    }
     /**
      * UDP Packet
      */
@@ -1120,6 +1125,38 @@ static void php_swoole_onWorkerStop(swServer *serv, int worker_id)
     }
 }
 
+static void php_swoole_onWorkerExit(swServer *serv, int worker_id)
+{
+    zval *zobject = (zval *) serv->ptr2;
+    zval *zworker_id;
+    zval **args[2];
+    zval *retval = NULL;
+
+    SW_MAKE_STD_ZVAL(zworker_id);
+    ZVAL_LONG(zworker_id, worker_id);
+
+    sw_zval_add_ref(&zobject);
+
+    SWOOLE_GET_TSRMLS;
+
+    args[0] = &zobject;
+    args[1] = &zworker_id;
+    if (sw_call_user_function_ex(EG(function_table), NULL, php_sw_server_callbacks[SW_SERVER_CB_onWorkerExit], &retval, 2, args, 0,
+            NULL TSRMLS_CC) == FAILURE)
+    {
+        swoole_php_fatal_error(E_WARNING, "onWorkerStop handler error.");
+    }
+    if (EG(exception))
+    {
+        zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+    }
+    sw_zval_ptr_dtor(&zworker_id);
+    if (retval != NULL)
+    {
+        sw_zval_ptr_dtor(&retval);
+    }
+}
+
 static void php_swoole_onUserWorkerStart(swServer *serv, swWorker *worker)
 {
     SWOOLE_GET_TSRMLS;
@@ -1368,19 +1405,19 @@ PHP_METHOD(swoole_server, __construct)
     //only cli env
     if (strcasecmp("cli", sapi_module.name) != 0)
     {
-        swoole_php_fatal_error(E_ERROR, "swoole_server must run at php_cli environment.");
+        swoole_php_fatal_error(E_ERROR, "swoole_server only can be used in PHP CLI mode.");
         RETURN_FALSE;
     }
 
     if (SwooleG.main_reactor != NULL)
     {
-        swoole_php_fatal_error(E_ERROR, "eventLoop has been created. Unable to create swoole_server.");
+        swoole_php_fatal_error(E_ERROR, "eventLoop has already been created. unable to create swoole_server.");
         RETURN_FALSE;
     }
 
     if (SwooleGS->start > 0)
     {
-        swoole_php_fatal_error(E_WARNING, "server is already running. Unable to create swoole_server.");
+        swoole_php_fatal_error(E_WARNING, "server is running. unable to create swoole_server.");
         RETURN_FALSE;
     }
 
@@ -1389,7 +1426,7 @@ PHP_METHOD(swoole_server, __construct)
 
     if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|lll", &serv_host, &host_len, &serv_port, &serv_mode, &sock_type) == FAILURE)
     {
-        swoole_php_fatal_error(E_ERROR, "invalid parameters.");
+        swoole_php_fatal_error(E_ERROR, "invalid swoole_server parameters.");
         return;
     }
 
@@ -1399,7 +1436,7 @@ PHP_METHOD(swoole_server, __construct)
     if (serv_mode == SW_MODE_THREAD || serv_mode == SW_MODE_BASE)
     {
         serv_mode = SW_MODE_SINGLE;
-        swoole_php_fatal_error(E_WARNING, "PHP can not running at multi-threading. Reset mode to SWOOLE_MODE_BASE");
+        swoole_php_fatal_error(E_WARNING, "can't use multi-threading in PHP. reset server mode to be SWOOLE_MODE_BASE");
     }
 #endif
     serv->factory_mode = serv_mode;
@@ -1416,7 +1453,7 @@ PHP_METHOD(swoole_server, __construct)
     {
         if (swserver_add_systemd_socket(serv) <= 0)
         {
-            swoole_php_fatal_error(E_ERROR, "add systemd socket failed.");
+            swoole_php_fatal_error(E_ERROR, "failed to add systemd socket.");
             return;
         }
     }
@@ -1425,7 +1462,7 @@ PHP_METHOD(swoole_server, __construct)
         swListenPort *port = swServer_add_port(serv, sock_type, serv_host, serv_port);
         if (!port)
         {
-            zend_throw_exception_ex(swoole_exception_class_entry_ptr, errno, "listen port[%s:%d] failed. Error: %s[%d].",
+            zend_throw_exception_ex(swoole_exception_class_entry_ptr, errno, "failed to listen server port[%s:%d]. Error: %s[%d].",
                     serv_host, serv_port, strerror(errno), errno TSRMLS_CC);
             return;
         }
@@ -1459,6 +1496,33 @@ PHP_METHOD(swoole_server, __construct)
     }
 }
 
+PHP_METHOD(swoole_server, __destruct)
+{
+    int i;
+    for (i = 0; i < PHP_SERVER_CALLBACK_NUM; i++)
+    {
+#ifdef PHP_SWOOLE_ENABLE_FASTCALL
+        if (php_sw_server_caches[i])
+        {
+            efree(php_sw_server_caches[i]);
+            php_sw_server_caches[i] = NULL;
+        }
+#endif
+    }
+
+    zval *port_object;
+    for (i = 0; i < server_port_list.num; i++)
+    {
+        port_object = server_port_list.zobjects[i];
+        efree(port_object);
+        server_port_list.zobjects[i] = NULL;
+    }
+
+    efree(server_port_list.zports);
+    server_port_list.zports = NULL;
+
+}
+
 PHP_METHOD(swoole_server, set)
 {
     zval *zset = NULL;
@@ -1469,7 +1533,7 @@ PHP_METHOD(swoole_server, set)
 
     if (SwooleGS->start > 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is running. Unable to execute swoole_server_set now.");
+        swoole_php_fatal_error(E_WARNING, "server is running. unable to execute function 'swoole_server_set'.");
         RETURN_FALSE;
     }
 
@@ -1478,27 +1542,39 @@ PHP_METHOD(swoole_server, set)
         return;
     }
 
-    php_swoole_array_separate(zset);
-
     swServer *serv = swoole_get_object(zobject);
 
+    php_swoole_array_separate(zset);
     vht = Z_ARRVAL_P(zset);
+
     //chroot
     if (php_swoole_array_get_value(vht, "chroot", v))
     {
         convert_to_string(v);
+        if (SwooleG.chroot)
+        {
+            sw_free(SwooleG.chroot);
+        }
         SwooleG.chroot = sw_strndup(Z_STRVAL_P(v), Z_STRLEN_P(v));
     }
     //user
     if (php_swoole_array_get_value(vht, "user", v))
     {
         convert_to_string(v);
+        if (SwooleG.user)
+        {
+            sw_free(SwooleG.user);
+        }
         SwooleG.user = sw_strndup(Z_STRVAL_P(v), Z_STRLEN_P(v));
     }
     //group
     if (php_swoole_array_get_value(vht, "group", v))
     {
         convert_to_string(v);
+        if (SwooleG.group)
+        {
+            sw_free(SwooleG.group);
+        }
         SwooleG.group = sw_strndup(Z_STRVAL_P(v), Z_STRLEN_P(v));
     }
     //daemonize
@@ -1511,6 +1587,10 @@ PHP_METHOD(swoole_server, set)
     if (php_swoole_array_get_value(vht, "pid_file", v))
     {
         convert_to_string(v);
+        if (serv->pid_file)
+        {
+            sw_free(serv->pid_file);
+        }
         serv->pid_file = sw_strndup(Z_STRVAL_P(v), Z_STRLEN_P(v));
     }
     //reactor thread num
@@ -1533,6 +1613,12 @@ PHP_METHOD(swoole_server, set)
             serv->worker_num = SwooleG.cpu_num;
         }
     }
+    //max wait time
+    if (php_swoole_array_get_value(vht, "max_wait_time", v))
+    {
+        convert_to_long(v);
+        serv->max_wait_time = (uint32_t) Z_LVAL_P(v);
+    }
     //dispatch_mode
     if (php_swoole_array_get_value(vht, "dispatch_mode", v))
     {
@@ -1556,6 +1642,10 @@ PHP_METHOD(swoole_server, set)
     if (php_swoole_array_get_value(vht, "log_file", v))
     {
         convert_to_string(v);
+        if (SwooleG.log_file)
+        {
+            sw_free(SwooleG.log_file);
+        }
         SwooleG.log_file = sw_strndup(Z_STRVAL_P(v), Z_STRLEN_P(v));
     }
     //log_level
@@ -1589,7 +1679,10 @@ PHP_METHOD(swoole_server, set)
     {
         convert_to_long(v);
         SwooleG.task_worker_num = (int) Z_LVAL_P(v);
-        task_callbacks = swHashMap_new(1024, NULL);
+        if (task_callbacks == NULL)
+        {
+            task_callbacks = swHashMap_new(1024, NULL);
+        }
     }
     //task ipc mode, 1,2,3
     if (php_swoole_array_get_value(vht, "task_ipc_mode", v))
@@ -1605,10 +1698,13 @@ PHP_METHOD(swoole_server, set)
         convert_to_string(v);
         if (Z_STRLEN_P(v) > SW_TASK_TMPDIR_SIZE - 30)
         {
-            swoole_php_fatal_error(E_ERROR, "task_tmpdir is too long, max size is %d.", SW_TASK_TMPDIR_SIZE - 1);
+            swoole_php_fatal_error(E_ERROR, "task_tmpdir is too long, the max size is %d.", SW_TASK_TMPDIR_SIZE - 1);
             return;
         }
-        SwooleG.task_tmpdir = emalloc(SW_TASK_TMPDIR_SIZE);
+        if (SwooleG.task_tmpdir == NULL)
+        {
+            SwooleG.task_tmpdir = emalloc(SW_TASK_TMPDIR_SIZE);
+        }
         SwooleG.task_tmpdir_len = snprintf(SwooleG.task_tmpdir, SW_TASK_TMPDIR_SIZE, "%s/swoole.task.XXXXXX", Z_STRVAL_P(v)) + 1;
     }
     //task_max_request
@@ -1706,9 +1802,38 @@ PHP_METHOD(swoole_server, set)
             swoole_php_fatal_error(E_ERROR, "option upload_tmp_dir [%s] is too long.", Z_STRVAL_P(v));
             RETURN_FALSE;
         }
+        if (serv->upload_tmp_dir)
+        {
+            sw_free(serv->upload_tmp_dir);
+        }
         serv->upload_tmp_dir = sw_strndup(Z_STRVAL_P(v), Z_STRLEN_P(v));
     }
-
+    /**
+     * http static file handler
+     */
+    if (php_swoole_array_get_value(vht, "enable_static_handler", v))
+    {
+        convert_to_boolean(v);
+        serv->enable_static_handler = Z_BVAL_P(v);
+    }
+    if (php_swoole_array_get_value(vht, "document_root", v))
+    {
+        convert_to_string(v);
+        if (serv->document_root)
+        {
+            sw_free(serv->document_root);
+        }
+        serv->document_root = sw_strndup(Z_STRVAL_P(v), Z_STRLEN_P(v));
+        if (serv->document_root[Z_STRLEN_P(v) - 1] == '/')
+        {
+            serv->document_root[Z_STRLEN_P(v) - 1] = 0;
+            serv->document_root_len = Z_STRLEN_P(v) - 1;
+        }
+        else
+        {
+            serv->document_root_len = Z_STRLEN_P(v);
+        }
+    }
     /**
      * buffer input size
      */
@@ -1735,12 +1860,14 @@ PHP_METHOD(swoole_server, set)
     zval *retval = NULL;
     zval *port_object = server_port_list.zobjects[0];
 
+    sw_zval_add_ref(&zobject);
     sw_zval_add_ref(&port_object);
     sw_zval_add_ref(&zset);
-    sw_zval_add_ref(&zobject);
-
     sw_zend_call_method_with_1_params(&port_object, swoole_server_port_class_entry_ptr, NULL, "set", &retval, zset);
-    zend_update_property(swoole_server_class_entry_ptr, zobject, ZEND_STRL("setting"), zset TSRMLS_CC);
+
+    zval *zsetting = php_swoole_read_init_property(swoole_server_class_entry_ptr, getThis(), ZEND_STRL("setting") TSRMLS_CC);
+    sw_php_array_merge(Z_ARRVAL_P(zsetting), Z_ARRVAL_P(zset));
+    sw_zval_ptr_dtor(&zset);
 
     RETURN_TRUE;
 }
@@ -1752,7 +1879,7 @@ PHP_METHOD(swoole_server, on)
 
     if (SwooleGS->start > 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is running. Unable to set event callback now.");
+        swoole_php_fatal_error(E_WARNING, "server is running. unable to register event callback function.");
         RETURN_FALSE;
     }
 
@@ -1766,7 +1893,7 @@ PHP_METHOD(swoole_server, on)
     zend_fcall_info_cache *func_cache = emalloc(sizeof(zend_fcall_info_cache));
     if (!sw_zend_is_callable_ex(cb, NULL, 0, &func_name, NULL, func_cache, NULL TSRMLS_CC))
     {
-        swoole_php_fatal_error(E_ERROR, "Function '%s' is not callable", func_name);
+        swoole_php_fatal_error(E_ERROR, "function '%s' is not callable", func_name);
         efree(func_name);
         return;
     }
@@ -1795,6 +1922,7 @@ PHP_METHOD(swoole_server, on)
         "WorkerStop",
         "Task",
         "Finish",
+        "WorkerExit",
         "WorkerError",
         "ManagerStart",
         "ManagerStop",
@@ -1835,7 +1963,7 @@ PHP_METHOD(swoole_server, on)
 
     if (l_property_name == 0)
     {
-        swoole_php_error(E_WARNING, "Unknown event types[%s]", Z_STRVAL_P(name));
+        swoole_php_error(E_WARNING, "unknown event types[%s]", Z_STRVAL_P(name));
 #ifdef PHP_SWOOLE_ENABLE_FASTCALL
         efree(func_cache);
 #endif
@@ -1864,7 +1992,7 @@ PHP_METHOD(swoole_server, listen)
 
     if (SwooleGS->start > 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is running. cannot add listener.");
+        swoole_php_fatal_error(E_WARNING, "server is running. can't add listener.");
         RETURN_FALSE;
     }
 
@@ -1888,7 +2016,7 @@ PHP_METHOD(swoole_server, addProcess)
 {
     if (SwooleGS->start > 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is running. cannot add process.");
+        swoole_php_fatal_error(E_WARNING, "server is running. can't add process.");
         RETURN_FALSE;
     }
 
@@ -1900,7 +2028,7 @@ PHP_METHOD(swoole_server, addProcess)
 
     if (ZVAL_IS_NULL(process))
     {
-        swoole_php_fatal_error(E_WARNING, "parameter 1 cannot be empty.");
+        swoole_php_fatal_error(E_WARNING, "the first parameter can't be empty.");
         RETURN_FALSE;
     }
 
@@ -1944,7 +2072,7 @@ PHP_METHOD(swoole_server, start)
 
     if (SwooleGS->start > 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is running. Unable to execute swoole_server::start.");
+        swoole_php_fatal_error(E_WARNING, "server is running. unable to execute swoole_server->start.");
         RETURN_FALSE;
     }
 
@@ -1966,7 +2094,7 @@ PHP_METHOD(swoole_server, start)
     ret = swServer_start(serv);
     if (ret < 0)
     {
-        swoole_php_fatal_error(E_ERROR, "start server failed. Error: %s", sw_error);
+        swoole_php_fatal_error(E_ERROR, "failed to start server. Error: %s", sw_error);
         RETURN_LONG(ret);
     }
     RETURN_TRUE;
@@ -1984,14 +2112,23 @@ PHP_METHOD(swoole_server, send)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
+#ifdef FAST_ZPP
+    ZEND_PARSE_PARAMETERS_START(2, 3)
+        Z_PARAM_ZVAL(zfd)
+        Z_PARAM_ZVAL(zdata)
+        Z_PARAM_OPTIONAL
+        Z_PARAM_LONG(server_socket)
+    ZEND_PARSE_PARAMETERS_END();
+#else
     if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "zz|l", &zfd, &zdata, &server_socket) == FAILURE)
     {
         return;
     }
+#endif
 
     char *data;
     int length = php_swoole_get_send_data(zdata, &data TSRMLS_CC);
@@ -2078,14 +2215,24 @@ PHP_METHOD(swoole_server, sendto)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
+#ifdef FAST_ZPP
+    ZEND_PARSE_PARAMETERS_START(3, 4)
+        Z_PARAM_STRING(ip, ip_len)
+        Z_PARAM_LONG(port)
+        Z_PARAM_STRING(data, len)
+        Z_PARAM_OPTIONAL
+        Z_PARAM_LONG(server_socket)
+    ZEND_PARSE_PARAMETERS_END();
+#else
     if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "sls|l", &ip, &ip_len, &port, &data, &len, &server_socket) == FAILURE)
     {
         return;
     }
+#endif
 
     if (len <= 0)
     {
@@ -2102,12 +2249,12 @@ PHP_METHOD(swoole_server, sendto)
 
     if (ipv6 == 0 && serv->udp_socket_ipv4 <= 0)
     {
-        swoole_php_fatal_error(E_WARNING, "You must add an UDP listener to server before using sendto.");
+        swoole_php_fatal_error(E_WARNING, "UDP listener has to be added before executing sendto.");
         RETURN_FALSE;
     }
     else if (ipv6 == 1 && serv->udp_socket_ipv6 <= 0)
     {
-        swoole_php_fatal_error(E_WARNING, "You must add an UDP6 listener to server before using sendto.");
+        swoole_php_fatal_error(E_WARNING, "UDP6 listener has to be added before executing sendto.");
         RETURN_FALSE;
     }
 
@@ -2140,7 +2287,7 @@ PHP_METHOD(swoole_server, sendfile)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
@@ -2161,20 +2308,28 @@ PHP_METHOD(swoole_server, close)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
     if (swIsMaster())
     {
-        swoole_php_fatal_error(E_WARNING, "Cannot close connection in master process.");
+        swoole_php_fatal_error(E_WARNING, "can't close the connections in master process.");
         RETURN_FALSE;
     }
 
+#ifdef FAST_ZPP
+    ZEND_PARSE_PARAMETERS_START(1, 2)
+        Z_PARAM_LONG(fd)
+        Z_PARAM_OPTIONAL
+        Z_PARAM_BOOL(reset)
+    ZEND_PARSE_PARAMETERS_END();
+#else
     if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l|b", &fd, &reset) == FAILURE)
     {
         return;
     }
+#endif
 
     swServer *serv = swoole_get_object(zobject);
     SW_CHECK_RETURN(serv->close(serv, (int )fd, (int )reset));
@@ -2187,13 +2342,13 @@ PHP_METHOD(swoole_server, confirm)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
     if (swIsMaster())
     {
-        swoole_php_fatal_error(E_WARNING, "Cannot confirm connection in master process.");
+        swoole_php_fatal_error(E_WARNING, "can't confirm the connections in master process.");
         RETURN_FALSE;
     }
 
@@ -2213,14 +2368,14 @@ PHP_METHOD(swoole_server, pause)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
     swServer *serv = swoole_get_object(zobject);
     if (serv->factory_mode != SW_MODE_SINGLE || swIsTaskWorker())
     {
-        swoole_php_fatal_error(E_WARNING, "cannot pause method.");
+        swoole_php_fatal_error(E_WARNING, "can't use the pause method.");
         RETURN_FALSE;
     }
 
@@ -2254,14 +2409,14 @@ PHP_METHOD(swoole_server, resume)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
     swServer *serv = swoole_get_object(zobject);
     if (serv->factory_mode != SW_MODE_SINGLE || swIsTaskWorker())
     {
-        swoole_php_fatal_error(E_WARNING, "cannot resume method.");
+        swoole_php_fatal_error(E_WARNING, "can't use the resume method.");
         RETURN_FALSE;
     }
 
@@ -2292,7 +2447,7 @@ PHP_METHOD(swoole_server, stats)
 {
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
@@ -2323,7 +2478,7 @@ PHP_METHOD(swoole_server, reload)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
@@ -2335,7 +2490,7 @@ PHP_METHOD(swoole_server, reload)
     int sig = only_reload_taskworker ? SIGUSR2 : SIGUSR1;
     if (kill(SwooleGS->manager_pid, sig) < 0)
     {
-        swoole_php_fatal_error(E_WARNING, "kill() failed. Error: %s[%d]", strerror(errno), errno);
+        swoole_php_fatal_error(E_WARNING, "failed to send the reload signal. Error: %s[%d]", strerror(errno), errno);
         RETURN_FALSE;
     }
     RETURN_TRUE;
@@ -2349,7 +2504,7 @@ PHP_METHOD(swoole_server, heartbeat)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
@@ -2424,6 +2579,8 @@ PHP_METHOD(swoole_server, taskwait)
 
     php_swoole_task_pack(&buf, data TSRMLS_CC);
 
+    int task_id = buf.info.fd;
+
     uint64_t notify;
     swEventData *task_result = &(SwooleG.task_result[SwooleWG.id]);
     bzero(task_result, sizeof(swEventData));
@@ -2434,18 +2591,27 @@ PHP_METHOD(swoole_server, taskwait)
     while (read(efd, &notify, sizeof(notify)) > 0);
 
     sw_atomic_fetch_add(&SwooleStats->tasking_num, 1);
-    if (swProcessPool_dispatch_blocking(&SwooleGS->task_workers, &buf, (int*) &dst_worker_id) >= 0)
+    int _dst_worker_id = (int) dst_worker_id;
+    if (swProcessPool_dispatch_blocking(&SwooleGS->task_workers, &buf, &_dst_worker_id) >= 0)
     {
         task_notify_pipe->timeout = timeout;
-        int ret = task_notify_pipe->read(task_notify_pipe, &notify, sizeof(notify));
-        if (ret > 0)
+        while(1)
         {
-            zval *task_notify_data = php_swoole_task_unpack(task_result TSRMLS_CC);
-            RETURN_ZVAL(task_notify_data, 0, 0);
-        }
-        else
-        {
-            swoole_php_fatal_error(E_WARNING, "taskwait failed. Error: %s[%d]", strerror(errno), errno);
+            if (task_notify_pipe->read(task_notify_pipe, &notify, sizeof(notify)) > 0)
+            {
+                if (task_result->info.fd != task_id)
+                {
+                    continue;
+                }
+                zval *task_notify_data = php_swoole_task_unpack(task_result TSRMLS_CC);
+                RETURN_ZVAL(task_notify_data, 0, 0);
+                break;
+            }
+            else
+            {
+                swoole_php_error(E_WARNING, "taskwait failed. Error: %s[%d]", strerror(errno), errno);
+                break;
+            }
         }
     }
     else
@@ -2523,7 +2689,7 @@ PHP_METHOD(swoole_server, taskWaitMulti)
         swTask_type(&buf) |= SW_TASK_WAITALL;
         dst_worker_id = -1;
         sw_atomic_fetch_add(&SwooleStats->tasking_num, 1);
-        if (swProcessPool_dispatch_blocking(&SwooleGS->task_workers, &buf, (int*) &dst_worker_id) < 0)
+        if (swProcessPool_dispatch_blocking(&SwooleGS->task_workers, &buf, &dst_worker_id) < 0)
         {
             sw_atomic_fetch_sub(&SwooleStats->tasking_num, 1);
             swoole_php_fatal_error(E_WARNING, "taskwait failed. Error: %s[%d]", strerror(errno), errno);
@@ -2602,14 +2768,23 @@ PHP_METHOD(swoole_server, task)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
+#ifdef FAST_ZPP
+    ZEND_PARSE_PARAMETERS_START(1, 3)
+        Z_PARAM_ZVAL(data)
+        Z_PARAM_OPTIONAL
+        Z_PARAM_LONG(dst_worker_id)
+        Z_PARAM_ZVAL(callback)
+    ZEND_PARSE_PARAMETERS_END();
+#else
     if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|lz", &data, &dst_worker_id, &callback) == FAILURE)
     {
         return;
     }
+#endif
 
     if (php_swoole_check_task_param(dst_worker_id TSRMLS_CC) < 0)
     {
@@ -2627,7 +2802,7 @@ PHP_METHOD(swoole_server, task)
         char *func_name = NULL;
         if (!sw_zend_is_callable(callback, 0, &func_name TSRMLS_CC))
         {
-            swoole_php_fatal_error(E_WARNING, "Function '%s' is not callable", func_name);
+            swoole_php_fatal_error(E_WARNING, "function '%s' is not callable", func_name);
             efree(func_name);
             return;
         }
@@ -2640,7 +2815,9 @@ PHP_METHOD(swoole_server, task)
 
     swTask_type(&buf) |= SW_TASK_NONBLOCK;
     sw_atomic_fetch_add(&SwooleStats->tasking_num, 1);
-    if (swProcessPool_dispatch(&SwooleGS->task_workers, &buf, (int*) &dst_worker_id) >= 0)
+
+    int _dst_worker_id = (int) dst_worker_id;
+    if (swProcessPool_dispatch(&SwooleGS->task_workers, &buf, &_dst_worker_id) >= 0)
     {
         RETURN_LONG(buf.info.fd);
     }
@@ -2649,7 +2826,6 @@ PHP_METHOD(swoole_server, task)
         sw_atomic_fetch_sub(&SwooleStats->tasking_num, 1);
         RETURN_FALSE;
     }
-
 }
 
 PHP_METHOD(swoole_server, sendMessage)
@@ -2662,7 +2838,7 @@ PHP_METHOD(swoole_server, sendMessage)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
@@ -2673,7 +2849,7 @@ PHP_METHOD(swoole_server, sendMessage)
 
     if (worker_id == SwooleWG.id)
     {
-        swoole_php_fatal_error(E_WARNING, "cannot send message to self.");
+        swoole_php_fatal_error(E_WARNING, "can't send messages to self.");
         RETURN_FALSE;
     }
 
@@ -2686,7 +2862,7 @@ PHP_METHOD(swoole_server, sendMessage)
 
     if (!serv->onPipeMessage)
     {
-        swoole_php_fatal_error(E_WARNING, "onPipeMessage is null, cannot use sendMessage.");
+        swoole_php_fatal_error(E_WARNING, "onPipeMessage is null, can't use sendMessage.");
         RETURN_FALSE;
     }
 
@@ -2709,14 +2885,20 @@ PHP_METHOD(swoole_server, finish)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
+#ifdef FAST_ZPP
+    ZEND_PARSE_PARAMETERS_START(1, 1)
+        Z_PARAM_ZVAL(data)
+    ZEND_PARSE_PARAMETERS_END();
+#else
     if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z", &data) == FAILURE)
     {
         return;
     }
+#endif
 
     swServer *serv = swoole_get_object(zobject);
     SW_CHECK_RETURN(php_swoole_task_finish(serv, data TSRMLS_CC));
@@ -2731,7 +2913,7 @@ PHP_METHOD(swoole_server, bind)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
@@ -2809,7 +2991,7 @@ PHP_METHOD(swoole_server, connection_info)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
@@ -2847,7 +3029,7 @@ PHP_METHOD(swoole_server, connection_info)
     {
         array_init(return_value);
 
-        swoole_php_error(E_DEPRECATED, "The udp connection_info is deprecated, use onPacket instead.");
+        swoole_php_error(E_DEPRECATED, "The UDP connection_info is deprecated, use onPacket instead.");
 
         if (ipv6_udp)
         {
@@ -2936,7 +3118,7 @@ PHP_METHOD(swoole_server, connection_list)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
@@ -3020,7 +3202,7 @@ PHP_METHOD(swoole_server, sendwait)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
@@ -3046,14 +3228,14 @@ PHP_METHOD(swoole_server, sendwait)
 
     if (serv->factory_mode != SW_MODE_SINGLE || swIsTaskWorker())
     {
-        swoole_php_fatal_error(E_WARNING, "cannot sendwait.");
+        swoole_php_fatal_error(E_WARNING, "can't sendwait.");
         RETURN_FALSE;
     }
 
     //UDP
     if (swServer_is_udp(fd))
     {
-        swoole_php_fatal_error(E_WARNING, "cannot sendwait.");
+        swoole_php_fatal_error(E_WARNING, "can't sendwait.");
         RETURN_FALSE;
     }
     //TCP
@@ -3071,14 +3253,20 @@ PHP_METHOD(swoole_server, exist)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
+#ifdef FAST_ZPP
+    ZEND_PARSE_PARAMETERS_START(1, 1)
+        Z_PARAM_LONG(fd)
+    ZEND_PARSE_PARAMETERS_END();
+#else
     if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &fd) == FAILURE)
     {
         return;
     }
+#endif
 
     swServer *serv = swoole_get_object(zobject);
 
@@ -3105,7 +3293,7 @@ PHP_METHOD(swoole_server, protect)
 
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
@@ -3137,13 +3325,13 @@ PHP_METHOD(swoole_server, shutdown)
 {
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
     if (kill(SwooleGS->master_pid, SIGTERM) < 0)
     {
-        swoole_php_sys_error(E_WARNING, "shutdown failed. kill(%d, SIGTERM) failed.", SwooleGS->master_pid);
+        swoole_php_sys_error(E_WARNING, "failed to shutdown. kill(%d, SIGTERM) failed.", SwooleGS->master_pid);
         RETURN_FALSE;
     }
     else
@@ -3156,7 +3344,7 @@ PHP_METHOD(swoole_server, stop)
 {
     if (SwooleGS->start == 0)
     {
-        swoole_php_fatal_error(E_WARNING, "Server is not running.");
+        swoole_php_fatal_error(E_WARNING, "server is not running.");
         RETURN_FALSE;
     }
 
